"use strict";
/*
 * Copyright 2020-2023 Delft University of Technology and SynTest contributors
 *
 * This file is part of SynTest Framework - SynTest JavaScript.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.OptionGroups = exports.StateStorageEventListenerPlugin = void 0;
const module_1 = require("@syntest/module");
const StateStorage_1 = require("./StateStorage");
/**
 * This graphing plugin creates a listener that creates an SVG based on the generated CFG.
 *
 * @author Dimitri Stallenberg
 */
class StateStorageEventListenerPlugin extends module_1.EventListenerPlugin {
    constructor(storageManager) {
        super("javascript-state-storage", 
        // eslint-disable-next-line @typescript-eslint/no-unsafe-argument, @typescript-eslint/no-var-requires, unicorn/prefer-module, @typescript-eslint/no-unsafe-member-access
        require("../../package.json").description);
        this.storageManager = storageManager;
    }
    setupEventListener() {
        const stateStore = this.args
            .javascriptStateStorageDirectory;
        const stateStorage = new StateStorage_1.StateStorage(this.storageManager, stateStore);
        process.on("exportExtractionComplete", (rootContext, filepath) => stateStorage.exportExtractionComplete(rootContext, filepath));
        process.on("elementExtractionComplete", (rootContext, filepath) => stateStorage.elementExtractionComplete(rootContext, filepath));
        process.on("relationExtractionComplete", (rootContext, filepath) => stateStorage.relationExtractionComplete(rootContext, filepath));
        process.on("objectTypeExtractionComplete", (rootContext, filepath) => stateStorage.objectTypeExtractionComplete(rootContext, filepath));
        process.on("typeResolvingComplete", (rootContext) => stateStorage.typeResolvingComplete(rootContext));
    }
    getOptions(tool, labels, command) {
        const optionsMap = new Map();
        if (!labels.includes("testing")) {
            return optionsMap;
        }
        if (command !== "test") {
            return optionsMap;
        }
        optionsMap.set("directory", {
            alias: [],
            default: "state",
            description: "The path where the state should be saved",
            group: OptionGroups.StateStorage,
            hidden: false,
            normalize: true,
            type: "string",
        });
        return optionsMap;
    }
    getOptionChoices() {
        return [];
    }
}
exports.StateStorageEventListenerPlugin = StateStorageEventListenerPlugin;
var OptionGroups;
(function (OptionGroups) {
    OptionGroups["StateStorage"] = "State Storage Options:";
})(OptionGroups = exports.OptionGroups || (exports.OptionGroups = {}));
//# sourceMappingURL=StateStorageEventListenerPlugin.js.map